@@ -4,43 +4,62 @@
 #' @include parse.R
 roxygen()
 
-register.preref.parsers(parse.value,
-                        'name',
-                        'aliases',
-                        'title',
-                        'usage',
-                        'references',
-                        'concept',
-                        'note',
-                        'seealso',
-                        'example',
-                        'examples',
-                        'keywords',
-                        'return',
-                        'author',
-                        'TODO',
-                        'format',
-                        'source')
+##' Substitutions of questionable characters with a hacker-joke to
+##' boot.
+substitutions=c(
+  `!`='bang',
+  `"`='quote',
+  `#`='hash',
+  `$`='cash',                           # sigil
+  `%`='grapes',
+  `&`='and',
+  `'`='single-quote',
+  `(`='open-paren',
+  `)`='close-paren',
+  `*`='star',
+  `+`='plus',
+  `,`='comma',
+  `-`='dash',
+  `.`='dot',
+  `/`='slash',
+  `:`='colon',
+  `;`='semi-colon',
+  `<`='less-than',
+  `=`='equals',
+  `>`='greater-than',
+  `?`='p',
+  `@`='asperand',
+  `[`='open-brace',
+  `\\`='backslash',
+  `]`='close-brace',
+  `^`='hat',
+  `_`='sub',
+  '`'='backtick',                       # let's add another ` to
+                                        # rectify syntax highlighting
+                                        # in emacs; thanks.
+  `{`='open-curly',
+  `|`='pipe',
+  `}`='close',
+  `~`='not'
+  )
 
-register.preref.parsers(parse.name.description,
-                        'param',
-                        'method')
+##' \code{NULL} if empty-string.
+##' @param string string to check
+##' @return \code{NULL} or identity
+nil.if.lambda <- function(string)
+  if (nchar(string)) string else NULL
 
-register.preref.parsers(parse.name,
-                        'docType')
-
-register.srcref.parser('setClass',
-                       function(pivot, expression)
-                       list(S4class=car(expression)))
-
-register.srcref.parser('setGeneric',
-                       function(pivot, expression)
-                       list(S4generic=car(expression)))
-
-register.srcref.parser('setMethod',
-                       function(pivot, expression)
-                       list(S4method=car(expression),
-                            signature=cadr(expression)))
+##' Translate file-system-questionable characters (i.e. punctuation
+##' within ASCII).
+##' @param filename the filename to translate
+##' @return the translated filename
+translate.questionable.characters <- function(filename)
+  do.call(Curry(paste, collapse="-"),
+          strapply(filename,
+                   pattern='([[:punct:]]|)([^[:punct:]]*|)',
+                   function(punctuation, letters)
+                   c(substitutions[nil.if.lambda(punctuation)],
+                     nil.if.lambda(letters))))
 
 #' Make an Rd roclet which parses the given files and, if specified, populates
 #' the given subdirectory with Rd files; or writes to standard out.  See
@@ -158,6 +177,44 @@ register.srcref.parser('setMethod',
 #' make.Rd.roclet
 make.Rd.roclet <- function(subdir=NULL,
                            verbose=TRUE) {
+  register.preref.parsers(parse.value,
+                          'name',
+                          'aliases',
+                          'title',
+                          'usage',
+                          'references',
+                          'concept',
+                          'note',
+                          'seealso',
+                          'example',
+                          'examples',
+                          'keywords',
+                          'return',
+                          'author',
+                          'TODO',
+                          'format',
+                          'source')
+
+  register.preref.parsers(parse.name.description,
+                          'param',
+                          'method')
+
+  register.preref.parsers(parse.name,
+                          'docType')
+
+  register.srcref.parser('setClass',
+                         function(pivot, expression)
+                         list(S4class=car(expression)))
+
+  register.srcref.parser('setGeneric',
+                         function(pivot, expression)
+                         list(S4generic=car(expression)))
+
+  register.srcref.parser('setMethod',
+                         function(pivot, expression)
+                         list(S4method=car(expression),
+                              signature=cadr(expression)))
+
   #' Translate a key and expressions into an Rd expression;
   #' multiple expressions take their own braces.
   #' @param key the expression's key
@@ -268,7 +325,9 @@ make.Rd.roclet <- function(subdir=NULL,
       name <- trim(name)
       if (!is.null(subdir)) {
         assign.parent('filename',
-                      file.path(subdir, sprintf('%s.Rd', name)),
+                      file.path(subdir,
+                                sprintf('%s.Rd',
+                                        translate.questionable.characters(name))),
                       environment())
         if (verbose)
           cat(sprintf('Writing %s to %s\n', name, filename))
@@ -299,11 +358,20 @@ make.Rd.roclet <- function(subdir=NULL,
   parse.formals <- function(partitum) {
     formals <- partitum$formals
     if (!is.null(formals)) {
-      name.defaults <- zip.c(names(formals), formals)
+      ## name.defaults <- zip.c(names(formals), formals)
+      name.defaults <-
+        zip.c(names(formals),
+              Map(function(formal) tryCatch(toString(formal),
+                                            error=function(e) '<closure>'),
+                  formals))
       args <-
         do.call(paste, c(Map(function(name.default) {
           name <- car(name.default)
           default <- cadr(name.default)
+          default <- gsubfn("\"(.*)\"",
+                            function(x)
+                            sprintf("\"%s\"", gsub("\"", "\\\\\"", x)),
+                            as.character(default))
           if (is.null.string(default))
             name
           else
